@@ -9,7 +9,7 @@
 # Copyright (c) 2003 by kaepapa <kaepapa@kaepapa.dip.jp>
 
 # grubmenu version
-VERSION = "grubmenu 0.2.2"
+VERSION = "grubmenu 0.2.5"
 
 # boot directory
 BOOT = "/boot"
@@ -29,6 +29,9 @@ VER_FILES = [['/etc/debian_version','DebianGNU/Linux'],
              ['/etc/redhat-release','Redhat Linux'],
              ['/etc/gentoo-release','Gentoo Linux']]
 
+# windows family
+WINDOWS = "Windows 95/98/Me/NT/2000/XP"
+
 # the character color on the grub menu
 STR_COLOR = ['black','blue','green','cyan','red','magenta','brown','light-gray','dark-gray',\
          'light-blue','light-green','light-cyan','light-red','light-magenta','yellow','white']
