@@ -32,6 +32,8 @@ ID_BTN_OPTIONS = wxNewId()
 ID_CHKBOX_SPLASH = wxNewId()
 ID_CHKBOX_COLOR = wxNewId()
 
+ID_TEXT_ENT_WIN = wxNewId()
+
 # the main window class which inherited wxFrame
 class ui_wxPython(wxFrame):
     __conf = config.config()
@@ -97,7 +99,7 @@ class ui_wxPython(wxFrame):
                                                choices=self.__conf.VM_LIST,
                                                style=wxCB_DROPDOWN|wxCB_READONLY)
         self.label_windows = wxStaticText(self.notebook_common, -1, _("Windows Entry (ex. /dev/hda1)"))
-        self.text_ctrl_windows = wxTextCtrl(self.notebook_common, -1, "")
+        self.text_ctrl_windows = wxTextCtrl(self.notebook_common, ID_TEXT_ENT_WIN, "")
         self.checkbox_splash = wxCheckBox(self.notebook_appearance, ID_CHKBOX_SPLASH, _("Splash"))
         self.text_ctrl_splash = wxTextCtrl(self.notebook_appearance, -1, "")
         self.button_splash = wxButton(self.notebook_appearance, ID_BTN_OPTIONS, "...")
@@ -144,6 +146,8 @@ class ui_wxPython(wxFrame):
         EVT_CHECKBOX(self, ID_CHKBOX_SPLASH, self.OnChkBoxSplashClick)
         EVT_CHECKBOX(self, ID_CHKBOX_COLOR, self.OnChkBoxColorClick)
 
+	EVT_TEXT(self, ID_TEXT_ENT_WIN, self.OnChangeTextCtrlWin)
+
         # setup is load
         self.loadConf()
 
@@ -154,9 +158,13 @@ class ui_wxPython(wxFrame):
         statusbar_fields = [""]
         for i in range(len(statusbar_fields)):
             self.statusbar.SetStatusText(statusbar_fields[i], i)
+        self.label_timeout.SetSize((250, 18))
+        self.label_kblayout.SetSize((250, 18))
         self.combo_box_kblayout.SetSelection(0)
+        self.label_defaultboot.SetSize((250, 18))
         self.combo_box_defaultboot.SetSize((250,24))
         self.combo_box_defaultboot.SetSelection(0)
+        self.label_windows.SetSize((250, 18))
         self.text_ctrl_splash.SetSize((270, 24))
         self.text_ctrl_splash.Enable(0)
         self.text_ctrl_splash.SetEditable(false)
@@ -210,19 +218,19 @@ class ui_wxPython(wxFrame):
         sizer_defaultboot = wxBoxSizer(wxHORIZONTAL)
         sizer_kblayout = wxBoxSizer(wxHORIZONTAL)
         sizer_timeout = wxBoxSizer(wxHORIZONTAL)
-        sizer_timeout.Add(self.label_timeout, 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, 155)
+        sizer_timeout.Add(self.label_timeout, 0, wxALIGN_CENTER_VERTICAL, 0)
         sizer_timeout.Add(self.text_ctrl_timeout, 0, wxALIGN_CENTER_VERTICAL, 0)
         sizer_common_main.Add(sizer_timeout, 1, wxEXPAND, 0)
         sizer_common_main.Add(20, 20, 0, 0, 0)
-        sizer_kblayout.Add(self.label_kblayout, 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, 102)
+        sizer_kblayout.Add(self.label_kblayout, 0, wxALIGN_CENTER_VERTICAL, 0)
         sizer_kblayout.Add(self.combo_box_kblayout, 0, wxALIGN_CENTER_VERTICAL, 0)
         sizer_common_main.Add(sizer_kblayout, 1, wxEXPAND, 0)
         sizer_common_main.Add(20, 20, 0, 0, 0)
-        sizer_defaultboot.Add(self.label_defaultboot, 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, 82)
+        sizer_defaultboot.Add(self.label_defaultboot, 0, wxALIGN_CENTER_VERTICAL, 0)
         sizer_defaultboot.Add(self.combo_box_defaultboot, 0, wxALIGN_CENTER_VERTICAL, 0)
         sizer_common_main.Add(sizer_defaultboot, 1, wxEXPAND, 0)
         sizer_common_main.Add(20, 20, 0, 0, 0)
-        sizer_windows.Add(self.label_windows, 0, wxRIGHT|wxALIGN_CENTER_VERTICAL, 11)
+        sizer_windows.Add(self.label_windows, 0, wxALIGN_CENTER_VERTICAL, 0)
         sizer_windows.Add(self.text_ctrl_windows, 0, wxALIGN_CENTER_VERTICAL, 0)
         sizer_common_main.Add(sizer_windows, 1, wxEXPAND, 0)
         sizer_common_whole.Add(sizer_common_main, 0, wxALL, 15)
@@ -370,10 +378,10 @@ class ui_wxPython(wxFrame):
 
         # write conf file
         self.__conf.writeconf()
-        conf = config.config()
+        self.__conf = config.config()
         
         # recreate view
-        st = create_menu.write_menu(conf)
+        st = create_menu.write_menu(self.__conf)
         self.text_ctrl_view.SetValue(st.getvalue())
         
 
@@ -393,7 +401,7 @@ class ui_wxPython(wxFrame):
 
     # onClick event method of options button
     def OnBtnOptionsClick(self, event):
-        dlg = wxFileDialog(self, "Choose a file", "/", "", "*.xpm", wxOPEN)
+        dlg = wxFileDialog(self, "Choose a file", "/", "", "XPM archive(*.xpm.gz)|*.xpm.gz|XPM file(*.xpm)|*.xpm", wxOPEN)
         if dlg.ShowModal() == wxID_OK:
             filename = dlg.GetFilename()
             directory = dlg.GetDirectory()
@@ -420,6 +428,8 @@ class ui_wxPython(wxFrame):
         # set windows entry
         if self.__conf.WIN != '':
             self.text_ctrl_windows.SetValue(self.__conf.WIN)
+            if self.__conf.DEFAULT == constants.WINDOWS:
+                self.combo_box_defaultboot.SetValue(constants.WINDOWS)
             
         # set splash
         if self.__conf.SPLASH != '':
@@ -443,8 +453,8 @@ class ui_wxPython(wxFrame):
                 self.combo_box_single_mode.SetSelection(self.__conf.VM_LIST.index(img)+1)
                 
         # set boot option
+        self.grid_entry.AppendRows(len(self.__conf.VM_LIST), False)
         for opt_list in self.__conf.OPTION_LIST:
-            self.grid_entry.AppendRows(1,false)
             self.grid_entry.SetCellValue(self.__conf.VM_LIST.index(opt_list[0]), 0, opt_list[0])
             self.grid_entry.SetReadOnly(self.__conf.VM_LIST.index(opt_list[0]), 0, True)
             option = ''
@@ -498,6 +508,19 @@ class ui_wxPython(wxFrame):
         self.combo_box_sel_strcolor.Enable(value)
         self.combo_box_sel_bgcolor.Enable(value)
 
+    # onChange event method of the text ctrl windows
+    def OnChangeTextCtrlWin(self, event):
+        if re.match("^/dev/.*", self.text_ctrl_windows.GetValue()) != None:
+            if self.combo_box_defaultboot.FindString(constants.WINDOWS) == -1:
+                self.combo_box_defaultboot.Append(constants.WINDOWS)
+        else:
+            try:
+                self.combo_box_defaultboot.Delete(self.combo_box_defaultboot.FindString(constants.WINDOWS))
+                self.combo_box_defaultboot.SetSelection(0)
+            except:
+                pass
+
+
 
 
 
